@@ -36,6 +36,11 @@
 #define errmsg_noopenfile "Can't open the configuration file"
 #define errmsg_nofile     "The configuration file doesn't exist"
 #define errmsg_conf       "Select Default Settings in the Setup Menu"
+#define errmsg_devicefile "Can't write on device file "
+#define errmsg_rate       "Wrong rate"
+#define errmsg_format     "Format error"
+#define errmsg_fragment   "Fragment error"
+#define errmsg_stereo     "Stereo error"
 
 #define main_menu_title  "Aldo Main Menu"
 #define main_menu_prompt "Your choice: "
