@@ -124,12 +124,12 @@ void OnClassicConf()
     classic_sec->option("StringsNumber")->set(tmp);
 
     Dialog<unsigned int> ask_skill(dlg_skill_title, main_menu_prompt);
-    ask_skill.add_choice(dlg_skill_choice1,libmorse::skill1);
-    ask_skill.add_choice(dlg_skill_choice2,libmorse::skill2);
-    ask_skill.add_choice(dlg_skill_choice3,libmorse::skill3);
-    ask_skill.add_choice(dlg_skill_choice4,libmorse::skill4);
-    ask_skill.add_choice(dlg_skill_choice5,libmorse::skill5);
-    ask_skill.add_choice(dlg_skill_choice6,libmorse::skill6);
+    ask_skill.add_choice(dlg_skill_choice1,libexercises::skill1);
+    ask_skill.add_choice(dlg_skill_choice2,libexercises::skill2);
+    ask_skill.add_choice(dlg_skill_choice3,libexercises::skill3);
+    ask_skill.add_choice(dlg_skill_choice4,libexercises::skill4);
+    ask_skill.add_choice(dlg_skill_choice5,libexercises::skill5);
+    ask_skill.add_choice(dlg_skill_choice6,libexercises::skill6);
     ask_skill.add_choice(dlg_skill_choice7,0);
 
     unsigned int skill = ask_skill.show();
@@ -139,15 +139,15 @@ void OnClassicConf()
 	{
 	    Dialog<unsigned int> ask_skill2(dlg_skill2_title, main_menu_prompt);
 
-	    ask_skill2.add_choice(dlg_skill2_choice1,libmorse::chars1);
-	    ask_skill2.add_choice(dlg_skill2_choice2,libmorse::chars2);
-	    ask_skill2.add_choice(dlg_skill2_choice3,libmorse::chars3);
-	    ask_skill2.add_choice(dlg_skill2_choice4,libmorse::chars4);
-	    ask_skill2.add_choice(dlg_skill2_choice5,libmorse::chars5);
-	    ask_skill2.add_choice(dlg_skill2_choice6,libmorse::numbrs);
+	    ask_skill2.add_choice(dlg_skill2_choice1,libexercises::chars1);
+	    ask_skill2.add_choice(dlg_skill2_choice2,libexercises::chars2);
+	    ask_skill2.add_choice(dlg_skill2_choice3,libexercises::chars3);
+	    ask_skill2.add_choice(dlg_skill2_choice4,libexercises::chars4);
+	    ask_skill2.add_choice(dlg_skill2_choice5,libexercises::chars5);
+	    ask_skill2.add_choice(dlg_skill2_choice6,libexercises::numbrs);
 	    ask_skill2.add_choice(dlg_skill2_choice7,0x1000);
-	    ask_skill2.add_choice(dlg_skill2_choice8,libmorse::submixed);
-	    ask_skill2.add_choice(dlg_skill2_choice9,libmorse::mixed);
+	    ask_skill2.add_choice(dlg_skill2_choice8,libexercises::submixed);
+	    ask_skill2.add_choice(dlg_skill2_choice9,libexercises::mixed);
 	    ask_skill2.add_choice(dlg_skill2_choice10,0);
 	    
 	    unsigned int skill2 = ask_skill2.show();
@@ -217,7 +217,7 @@ void OnResetDefault()
     classic_sec->option("StringsNumber")->set(3);
 
     classic_sec->add_option("Skill");
-    classic_sec->option("Skill")->set(libmorse::skill1);
+    classic_sec->option("Skill")->set(libexercises::skill1);
 	
     fileconf.add_section("Koch");
     libdatafile::sec_it koch_sec = fileconf.section("Koch");
